@@ -20,6 +20,8 @@ import multiprocessing as mp
 from jinja2 import Environment, FileSystemLoader
 from tkinter import *
 from tkinter import filedialog
+from tkinter import messagebox as mbox
+from tkinter.scrolledtext import ScrolledText
 
 
 class AppGui:
@@ -193,10 +195,6 @@ class AppGui:
 
     # Menu commands
 
-    def dummy(self):
-        """ This method is a dummy method to connect buttons for testing.  """
-        print("Widget connected to a dummy command.")
-
     def quit(self):
         """ Cleans the working directory and quits."""
         # If the status are "not saved" then the leftover files are safe to be purged.
@@ -257,7 +255,7 @@ class AppGui:
         elif self.choices['format'] == "json":
             self.clean_output = file_content
         else:
-            print("Bad file format.")
+            mb.showerror("The selected file format is not supported.")
         # Update the file status on Info panel
         self.saved_status = "saved"
         self.update_locked_field(self.esavedone, "saved")
@@ -309,7 +307,6 @@ class AppGui:
 
     def save_file(self):
         """ Saves the file into the selected location. """
-        print(self.choices['filename'], self.choices['format'])
         # Use the self.choices to construct the path and target to save the data.
         filename = f"{self.choices['filename']}.{self.choices['format']}"
         filename = os.path.join(self.choices['path'], filename)
@@ -336,7 +333,6 @@ class AppGui:
         """ Use filedialog to get the path and name of the input file. """
         filename = filedialog.askopenfilename(filetypes=[("json file", "*.json")])
         self.choices['inputfile'] = filename
-        print(self.choices['inputfile'])
         self.handle_filenames(filename)
 
     def set_format(self, form):
@@ -385,7 +381,7 @@ class AppGui:
     def init_record_frame(self):
         """ Initiate the widgets for the Recording frame. """
         self.destroy_widgets(self.functions)
-        self.text = Text(self.functions, width=85, height=30)
+        self.text = ScrolledText(self.functions, width=85, height=30)
         self.text.grid(column=0,row=0, columnspan=5)
         self.text.delete("0.1", END)
         self.text.insert("0.1", self.reclines)
@@ -394,11 +390,11 @@ class AppGui:
         self.stop = Button(self.functions, width=10, text="Stop", background="#DD0033", command=self.stop_recording)
         self.stop.grid(column=1, row=1, pady=5)
         self.stop.configure(state='disabled')
-        self.showraw = Button(self.functions, width=10, text="Show raw", command=self.show_raw_json)
+        self.showraw = Button(self.functions, width=10, text="Raw", command=self.show_raw_json)
         self.showraw.grid(column=2, row=1, pady=5)
-        self.showclean = Button(self.functions, width=10, text="Show clean", command=self.show_clean_json)
+        self.showclean = Button(self.functions, width=10, text="Clean", command=self.show_clean_json)
         self.showclean.grid(column=3, row=1, pady=5)
-        self.showformatted = Button(self.functions, width=10, text="Show formatted", command=self.show_formatted)
+        self.showformatted = Button(self.functions, width=10, text="Formatted", command=self.show_formatted)
         self.showformatted.grid(column=4, row=1, pady=5)
         # Disable "Show" buttons if no output is ready.
         if not self.clean_output:
@@ -559,7 +555,6 @@ class AppGui:
             # tweaking.
             self.current_event = self.clean_output[first_key]
             self.display_event(first_key, self.current_event)
-            print("Datakeys exist, editing them.")
         # If there are data, but we do want to add an entry
         elif self.datakeys and self.choices['report'] == 'create':
             self.createit.configure(state='normal')
@@ -567,7 +562,6 @@ class AppGui:
             self.previous.configure(state="disabled")
             self.next.configure(state="disabled")
             self.saveit.configure(state="disabled")
-            print("Datakeys exist, creating more.")
         # If no data are available for editting, do not allow any interaction
         elif not self.datakeys and self.choices['report'] == 'edit':
             self.saveit.configure(state="disabled")
@@ -575,17 +569,15 @@ class AppGui:
             self.next.configure(state="disabled")
             self.deleteit.configure(state='disabled')
             self.createit.configure(state='disabled')
-            print("No datakeys but call for edit.")
         # If there are no data, we cannot delete them.
         elif not self.datakeys and self.choices['report'] == 'create':
-            print("No datakeys, want to create")
             self.deleteit.configure(state='disabled')
             self.saveit.configure(state="disabled")
             self.previous.configure(state="disabled")
             self.next.configure(state="disabled")
         else:
             # This should not happen.
-            print("Special setting in buttons occurred. Check.")
+            mbox.showerror("An unexpected error happened.")
         # Read from the clean output and create a list of its keys for
         # navigating in the data.
         # Database pointer
@@ -639,7 +631,6 @@ class AppGui:
             self.update_locked_field(self.ehorizontal, event['horizontal'], opened=True)
         if 'text' in keys:
             self.update_locked_field(self.etext, event['text'], opened=True)
-        print(event)
 
     def edit_events(self):
         """ Starts editing existing events. """
@@ -821,6 +812,7 @@ class AppGui:
         # Do not let it go into negative values in order not
         # skip to the end of list.
         if self.pointer < 0:
+            mbox.showinfo("Info", "You have reached the beginning of the recording.")
             self.pointer = 0
         # If we have data available
         if self.datakeys:
@@ -832,7 +824,7 @@ class AppGui:
                 self.clear_edit_widgets("readonly")
                 self.display_event(timestamp, self.current_event)
             except IndexError:
-                print("The data list seems to be empty.")
+                mbox.showerror("Error", "There are no records to browse.")
 
     def skip_next(self):
         """ Navigate to a next entry in the database of events. """
@@ -850,7 +842,7 @@ class AppGui:
             except IndexError:
                 # To make sure the pointer does not point outside of the list
                 self.pointer -= 1
-                print("Already at the end of report.")
+                mbox.showinfo("Info", "You have reached the end of recording.")
 
     def delete_event(self):
         """ Deletes currently displayed event from the self.clean_output
